==> risecx_chat_client-1.2.1%2B1.tar.gz: lib/widgets/chat/message-list.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:risecx_chat_client/blocs/blocs.dart';
import 'package:risecx_chat_client/widgets/commons/empty_warning_widget.dart';
import 'message-list-item.dart';

class MessageList extends StatefulWidget {
  final Function onPayloadPress;
  final Function onMediaView;
  final dynamic user;
  final ChatBloc chatBloc;
  const MessageList(
      {Key key,
      this.onPayloadPress,
      this.onMediaView,
      this.user,
      @required this.chatBloc})
      : super(key: key);

  @override
  _MessageListState createState() => _MessageListState();
}

class _MessageListState extends State<MessageList> {
  ScrollController _scrollController;
  List<dynamic> filteredList = [];

  @override
  void initState() {
    super.initState();
    _scrollController = ScrollController();
  }

  void _scrollDown() {
    Timer(Duration(microseconds: 100), () {
      if (_scrollController.hasClients &&
          _scrollController.position.viewportDimension <
              _scrollController.position.maxScrollExtent)
        _scrollController.animateTo(_scrollController.position.maxScrollExtent,
            curve: Curves.linear, duration: Duration(milliseconds: 500));
    });
  }

  void _recoveryHistoryMessages() {
    widget.chatBloc.getHistory(widget.user);
  }
  @override
  Widget build(BuildContext context) {
    return StreamBuilder(
      stream: widget.chatBloc.messagesListStream,
      builder: (BuildContext context, AsyncSnapshot snapshot) {
        if (snapshot.hasError) return Text(snapshot.error);
        if (snapshot.data == null) {
          _recoveryHistoryMessages();
        }
        if (snapshot.hasData) {
          _scrollDown();
        }
        if (snapshot.data is List && snapshot.data.length == 0) {
          return EmptyWarningWidget(
            Icons.chat_bubble,
            message: 'Please say "hi"',
          );
    }

    if (snapshot.data is List && snapshot.data.length > 0) {
      filteredList = List.from(snapshot.data).where((element) => element['type'] != 'typing').toList();
    }
    
    return ListView.builder(
      controller: _scrollController,
      itemCount: filteredList != null ? filteredList.length : 0,
      shrinkWrap: true,
      itemBuilder: (context, index) => MessageItem(
        chatBloc: widget.chatBloc,
        message: filteredList[index],
        onPayloadPress: widget.onPayloadPress,
        onMediaView: widget.onMediaView,
      ),
    );
    },
  );
}

  // @override
  // Widget build(BuildContext context) {
  //   return StreamBuilder(
  //     stream: widget.chatBloc.messagesListStream,
  //     builder: (BuildContext context, AsyncSnapshot snapshot) {
  //       if (snapshot.hasError) return Text(snapshot.error);
  //       if (snapshot.data == null) {
  //         _recoveryHistoryMessages();
  //       }
  //       if (snapshot.hasData) {
  //         _scrollDown();
  //       }
  //       if (snapshot.data is List && snapshot.data.length == 0) {
  //         return EmptyWarningWidget(
  //           Icons.chat_bubble,
  //           message: 'Please say "hi"',
  //         );
  //       }
  //
  //       return ListView.builder(
  //         controller: _scrollController,
  //         itemCount: snapshot.data != null ? snapshot.data.length : 0,
  //         shrinkWrap: true,
  //         itemBuilder: (context, index) => MessageItem(
  //           chatBloc: widget.chatBloc,
  //           message: snapshot.data[index],
  //           onPayloadPress: widget.onPayloadPress,
  //           onMediaView: widget.onMediaView,
  //         ),
  //       );
  //     },
  //   );
  // }
}

==> risecx_chat_client-1.2.3%2B1.tar.gz: lib/widgets/chat/message-list.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:risecx_chat_client/blocs/blocs.dart';
import 'package:risecx_chat_client/widgets/commons/empty_warning_widget.dart';
import 'message-list-item.dart';

class MessageList extends StatefulWidget {
  final Function onPayloadPress;
  final Function onMediaView;
  final dynamic user;
  final ChatBloc chatBloc;
  final bool disableHistory;
  const MessageList(
      {Key key,
      this.onPayloadPress,
      this.onMediaView,
      this.user,
      @required this.chatBloc,
      this.disableHistory})
      : super(key: key);

  @override
  _MessageListState createState() => _MessageListState();
}

class _MessageListState extends State<MessageList> {
  ScrollController _scrollController;
  List<dynamic> filteredList = [];

  @override
  void initState() {
    super.initState();
    _scrollController = ScrollController();
  }

  void _scrollDown() {
    Timer(Duration(microseconds: 100), () {
      if (_scrollController.hasClients &&
          _scrollController.position.viewportDimension <
              _scrollController.position.maxScrollExtent)
        _scrollController.animateTo(_scrollController.position.maxScrollExtent,
            curve: Curves.linear, duration: Duration(milliseconds: 500));
    });
  }

  void _recoveryHistoryMessages() async {
    try {
      if (widget.disableHistory == false)
        await widget.chatBloc.getHistory(widget.user);
    } catch (e) {
      print(e);
    }
  }

  @override
  Widget build(BuildContext context) {
    return StreamBuilder(
      stream: widget.chatBloc.messagesListStream,
      builder: (BuildContext context, AsyncSnapshot snapshot) {
        if (snapshot.hasError) return Text(snapshot.error);
        if (snapshot.data == null) {
          _recoveryHistoryMessages();
        }
        if (snapshot.hasData) {
          _scrollDown();
        }
        if (snapshot.data is List && snapshot.data.length == 0) {
          return EmptyWarningWidget(
            Icons.chat_bubble,
            message: 'Please say "hi"',
          );
        }

        if (snapshot.data is List && snapshot.data.length > 0) {
          filteredList = List.from(snapshot.data)
              .where((element) => element['type'] != 'typing')
              .toList();
        }

        return ListView.builder(
          controller: _scrollController,
          itemCount: filteredList != null ? filteredList.length : 0,
          shrinkWrap: true,
          itemBuilder: (context, index) => MessageItem(
            chatBloc: widget.chatBloc,
            message: filteredList[index],
            onPayloadPress: widget.onPayloadPress,
            onMediaView: widget.onMediaView,
          ),
        );
      },
    );
  }
}
